Changelog
=========


Unreleased_
-----------


v0.1.0 - 2019-08-22
-------------------

* Loading of the RADS and PyRADS XML files via :code:`load_config` function.
* Locating the RADS dataroot with the :code:`get_dataroot` function.


.. _Unreleased: https://github.com/ccarocean/pyrads/compare/v0.1.0...HEAD
